updateCircles method
Updates circle configuration.
Change listeners are notified once the update has been made on the platform side.
The returned Future completes after listeners have been notified.
Implementation
Future<void> updateCircles(CircleUpdates circleUpdates, {required int mapId}) {
throw UnimplementedError('updateCircles() has not been implemented.');
}