updatePolylines method

Future<void> updatePolylines(
  1. PolylineUpdates polylineUpdates, {
  2. required int mapId,
})

Updates polyline configuration.

Change listeners are notified once the update has been made on the platform side.

The returned Future completes after listeners have been notified.

Implementation

Future<void> updatePolylines(PolylineUpdates polylineUpdates, {required int mapId}) {
  throw UnimplementedError('updatePolylines() has not been implemented.');
}