diffFrom method

Returns a new options object containing only the values of this instance that are different from other.

Implementation

MapConfiguration diffFrom(MapConfiguration other) {
  return MapConfiguration(
    webCameraControlPosition: webCameraControlPosition != other.webCameraControlPosition
        ? webCameraControlPosition
        : null,
    webCameraControlEnabled: webCameraControlEnabled != other.webCameraControlEnabled
        ? webCameraControlEnabled
        : null,
    webGestureHandling: webGestureHandling != other.webGestureHandling
        ? webGestureHandling
        : null,
    compassEnabled: compassEnabled != other.compassEnabled ? compassEnabled : null,
    mapToolbarEnabled: mapToolbarEnabled != other.mapToolbarEnabled ? mapToolbarEnabled : null,
    cameraTargetBounds: cameraTargetBounds != other.cameraTargetBounds
        ? cameraTargetBounds
        : null,
    mapType: mapType != other.mapType ? mapType : null,
    minMaxZoomPreference: minMaxZoomPreference != other.minMaxZoomPreference
        ? minMaxZoomPreference
        : null,
    rotateGesturesEnabled: rotateGesturesEnabled != other.rotateGesturesEnabled
        ? rotateGesturesEnabled
        : null,
    scrollGesturesEnabled: scrollGesturesEnabled != other.scrollGesturesEnabled
        ? scrollGesturesEnabled
        : null,
    tiltGesturesEnabled: tiltGesturesEnabled != other.tiltGesturesEnabled
        ? tiltGesturesEnabled
        : null,
    fortyFiveDegreeImageryEnabled:
        fortyFiveDegreeImageryEnabled != other.fortyFiveDegreeImageryEnabled
        ? fortyFiveDegreeImageryEnabled
        : null,
    trackCameraPosition: trackCameraPosition != other.trackCameraPosition
        ? trackCameraPosition
        : null,
    zoomControlsEnabled: zoomControlsEnabled != other.zoomControlsEnabled
        ? zoomControlsEnabled
        : null,
    zoomGesturesEnabled: zoomGesturesEnabled != other.zoomGesturesEnabled
        ? zoomGesturesEnabled
        : null,
    liteModeEnabled: liteModeEnabled != other.liteModeEnabled ? liteModeEnabled : null,
    myLocationEnabled: myLocationEnabled != other.myLocationEnabled ? myLocationEnabled : null,
    myLocationButtonEnabled: myLocationButtonEnabled != other.myLocationButtonEnabled
        ? myLocationButtonEnabled
        : null,
    padding: padding != other.padding ? padding : null,
    indoorViewEnabled: indoorViewEnabled != other.indoorViewEnabled ? indoorViewEnabled : null,
    trafficEnabled: trafficEnabled != other.trafficEnabled ? trafficEnabled : null,
    buildingsEnabled: buildingsEnabled != other.buildingsEnabled ? buildingsEnabled : null,
    mapTypeControlEnabled: mapTypeControlEnabled != other.mapTypeControlEnabled
        ? mapTypeControlEnabled
        : null,
    fullscreenControlEnabled: fullscreenControlEnabled != other.fullscreenControlEnabled
        ? fullscreenControlEnabled
        : null,
    streetViewControlEnabled: streetViewControlEnabled != other.streetViewControlEnabled
        ? streetViewControlEnabled
        : null,
    mapId: mapId != other.mapId ? mapId : null,
    style: style != other.style ? style : null,
    markerType: markerType != other.markerType ? markerType : null,
    colorScheme: colorScheme != other.colorScheme ? colorScheme : null,
  );
}