hideMarkerInfoWindow method
Programmatically hide the Info Window for a Marker.
The markerId must match one of the markers on the map.
An invalid markerId triggers an "Invalid markerId" error.
- See also:
- showMarkerInfoWindow to show the Info Window.
- isMarkerInfoWindowShown to check if the Info Window is showing.
Implementation
@override
Future<void> hideMarkerInfoWindow(MarkerId markerId, {required int mapId}) {
return channel(
mapId,
).invokeMethod<void>('markers#hideInfoWindow', <String, String>{'markerId': markerId.value});
}