showMarkerInfoWindow method
Programmatically show the Info Window for a Marker.
The markerId must match one of the markers on the map.
An invalid markerId triggers an "Invalid markerId" error.
- See also:
- hideMarkerInfoWindow to hide the Info Window.
- isMarkerInfoWindowShown to check if the Info Window is showing.
Implementation
@override
Future<void> showMarkerInfoWindow(MarkerId markerId, {required int mapId}) {
return channel(
mapId,
).invokeMethod<void>('markers#showInfoWindow', <String, String>{'markerId': markerId.value});
}