updateHeatmaps method
Updates heatmap configuration.
Change listeners are notified once the update has been made on the platform side.
The returned Future completes after listeners have been notified.
Implementation
@override
Future<void> updateHeatmaps(HeatmapUpdates heatmapUpdates, {required int mapId}) {
return channel(mapId).invokeMethod<void>(
'heatmaps#update',
serializeMapsObjectUpdates(heatmapUpdates, serializeHeatmap),
);
}