updatePolylines method
Updates polyline configuration.
Change listeners are notified once the update has been made on the platform side.
The returned Future completes after listeners have been notified.
Implementation
@override
Future<void> updatePolylines(PolylineUpdates polylineUpdates, {required int mapId}) {
return channel(mapId).invokeMethod<void>('polylines#update', polylineUpdates.toJson());
}