updatePolygons method
Updates polygon configuration.
Change listeners are notified once the update has been made on the platform side.
The returned Future completes after listeners have been notified.
Implementation
Future<void> updatePolygons(PolygonUpdates polygonUpdates, {required int mapId}) {
throw UnimplementedError('updatePolygons() has not been implemented.');
}