updatePolylines method
Updates polyline configuration.
Change listeners are notified once the update has been made on the platform side.
The returned Future completes after listeners have been notified.
Implementation
Future<void> updatePolylines(PolylineUpdates polylineUpdates, {required int mapId}) {
throw UnimplementedError('updatePolylines() has not been implemented.');
}