updateMarkers method
Updates marker configuration.
Change listeners are notified once the update has been made on the platform side.
The returned Future completes after listeners have been notified.
Implementation
@override
Future<void> updateMarkers(MarkerUpdates markerUpdates, {required int mapId}) {
return channel(mapId).invokeMethod<void>('markers#update', markerUpdates.toJson());
}