updatePolygons method
Updates polygon configuration.
Change listeners are notified once the update has been made on the platform side.
The returned Future completes after listeners have been notified.
Implementation
@override
Future<void> updatePolygons(PolygonUpdates polygonUpdates, {required int mapId}) {
return channel(mapId).invokeMethod<void>('polygons#update', polygonUpdates.toJson());
}